[dts] [PATCH]Convert dts to new Tx offload API

Lijuan Tu lijuanx.a.tu at intel.com
Tue Jan 16 16:17:13 CET 2018


dpdk18.02 tx offloads API changed.
dpdk commit 28da7d752bf0("app/testpmd: remove txqflags option")

As app/testpmd is now using the new Ethdev offloads API,
and there is necessary to change DTS to align to it.

Signed-off-by: Lijuan Tu <lijuanx.a.tu at intel.com>
---
 framework/pmd_output.py                              |  6 +++---
 test_plans/ddp_gtp_test_plan.rst                     |  2 +-
 test_plans/ddp_mpls_test_plan.rst                    |  2 +-
 test_plans/etag_test_plan.rst                        |  2 +-
 test_plans/external_mempool_handler_test_plan.rst    | 10 +++++-----
 .../fortville_rss_granularity_config_test_plan.rst   |  8 ++++----
 test_plans/generic_flow_api_test_plan.rst            | 10 +++++-----
 test_plans/ipgre_test_plan.rst                       |  8 ++++----
 test_plans/macsec_for_ixgbe_test_plan.rst            | 10 +++++-----
 test_plans/pmd_bonded_test_plan.rst                  |  2 +-
 test_plans/pmdrss_hash_test_plan.rst                 |  2 +-
 test_plans/qinq_filter_test_plan.rst                 |  8 ++++----
 test_plans/tx_preparation_test_plan.rst              |  4 ++--
 test_plans/uni_pkt_test_plan.rst                     |  2 +-
 test_plans/vf_daemon_test_plan.rst                   |  2 +-
 test_plans/vf_jumboframe_test_plan.rst               |  2 +-
 test_plans/vf_macfilter_test_plan.rst                |  4 ++--
 test_plans/vf_packet_rxtx_test_plan.rst              |  2 +-
 test_plans/vf_pf_reset_test_plan.rst                 | 14 +++++++-------
 test_plans/vf_rss_test_plan.rst                      |  2 +-
 test_plans/vf_to_vf_nic_bridge_test_plan.rst         |  4 ++--
 test_plans/vf_vlan_test_plan.rst                     |  4 ++--
 test_plans/virtio_1.0_test_plan.rst                  | 20 ++++++++++----------
 test_plans/vlan_ethertype_config_test_plan.rst       | 12 ++++++------
 test_plans/vxlan_sample_test_plan.rst                |  2 +-
 test_plans/vxlan_test_plan.rst                       |  8 ++++----
 tests/TestSuite_fortville_rss_granularity_config.py  | 12 ++++++------
 tests/TestSuite_ipgre.py                             |  4 ++--
 tests/TestSuite_nvgre.py                             |  8 ++++----
 tests/TestSuite_pmd.py                               |  2 +-
 tests/TestSuite_pmd_bonded.py                        |  2 +-
 tests/TestSuite_pmdrss_hash.py                       |  2 +-
 tests/TestSuite_qinq_filter.py                       | 16 ++++++++--------
 tests/TestSuite_sriov_kvm.py                         |  2 +-
 tests/TestSuite_tso.py                               |  6 +++---
 tests/TestSuite_uni_pkt.py                           |  2 +-
 tests/TestSuite_vf_jumboframe.py                     | 10 +++++-----
 tests/TestSuite_vf_offload.py                        |  4 ++--
 tests/TestSuite_vhost_cuse_one_copy_one_vm.py        |  4 ++--
 ...stSuite_vhost_loopback_performance_virtio_user.py |  6 +++---
 tests/TestSuite_vhost_pmd_xstats.py                  |  2 +-
 tests/TestSuite_vhost_qemu_pvp_performance.py        |  4 ++--
 tests/TestSuite_vhost_user_one_copy_one_vm.py        |  4 ++--
 tests/TestSuite_vxlan.py                             | 20 ++++++++++----------
 tests/TestSuite_vxlan_sample.py                      |  2 +-
 45 files changed, 132 insertions(+), 132 deletions(-)

diff --git a/test_plans/ddp_gtp_test_plan.rst b/test_plans/ddp_gtp_test_plan.rst
index 3e6c954..aedf45f 100644
--- a/test_plans/ddp_gtp_test_plan.rst
+++ b/test_plans/ddp_gtp_test_plan.rst
@@ -82,7 +82,7 @@ Prerequisites
    port topology mode, add txq/rxq to enable multi-queues. In general, PF's 
    max queue is 64, VF's max queue is 4::
 
-    ./testpmd -c f -n 4 -- -i --pkt-filter-mode=perfect --port-topology=chained --txqflags=0 --txq=64 --rxq=64  
+    ./testpmd -c f -n 4 -- -i --pkt-filter-mode=perfect --port-topology=chained --tx-offloads=0x8fff --txq=64 --rxq=64  
 
 
 Test Case: Load dynamic device personalization 
diff --git a/test_plans/ddp_mpls_test_plan.rst b/test_plans/ddp_mpls_test_plan.rst
index b38b469..cce8efb 100644
--- a/test_plans/ddp_mpls_test_plan.rst
+++ b/test_plans/ddp_mpls_test_plan.rst
@@ -70,7 +70,7 @@ Prerequisites
    enable multi-queues. In general, PF's max queue is 64, VF's max queue
    is 4::
 
-     ./testpmd -c f -n 4 -- -i --port-topology=chained --txqflags=0
+     ./testpmd -c f -n 4 -- -i --port-topology=chained --tx-offloads=0x8fff
      --txq=4 --rxq=4
 
 
diff --git a/test_plans/etag_test_plan.rst b/test_plans/etag_test_plan.rst
index 5a71791..6350d64 100644
--- a/test_plans/etag_test_plan.rst
+++ b/test_plans/etag_test_plan.rst
@@ -87,7 +87,7 @@ Prerequisites
 
 6. Start guest testpmd, set it in mac forward mode::
 
-      testpmd -c 0x3 -n 1  -- -i  --txqflags=0x0
+      testpmd -c 0x3 -n 1  -- -i  --tx-offloads=0x8fff
       testpmd> set fwd mac
       testpmd> start
 
diff --git a/test_plans/external_mempool_handler_test_plan.rst b/test_plans/external_mempool_handler_test_plan.rst
index e545045..be53272 100644
--- a/test_plans/external_mempool_handler_test_plan.rst
+++ b/test_plans/external_mempool_handler_test_plan.rst
@@ -50,7 +50,7 @@ Test Case 1: Multiple producers and multiple consumers
 
 3. Start testpmd with two ports and start forwarding::
 
-      testpmd -c 0x6 -n 4  -- -i --portmask=0x3 --txqflags=0
+      testpmd -c 0x6 -n 4  -- -i --portmask=0x3 --tx-offloads=0x8fff
       testpmd> set fwd mac
       testpmd> start
 
@@ -68,7 +68,7 @@ Test Case 2: Single producer and Single consumer
 
 3. Start testpmd with two ports and start forwarding::
 
-      testpmd -c 0x6 -n 4  -- -i --portmask=0x3 --txqflags=0
+      testpmd -c 0x6 -n 4  -- -i --portmask=0x3 --tx-offloads=0x8fff
       testpmd> set fwd mac
       testpmd> start
 
@@ -86,7 +86,7 @@ Test Case 3: Single producer and Multiple consumers
 
 3. Start testpmd with two ports and start forwarding::
 
-      testpmd -c 0x6 -n 4  -- -i --portmask=0x3 --txqflags=0
+      testpmd -c 0x6 -n 4  -- -i --portmask=0x3 --tx-offloads=0x8fff
       testpmd> set fwd mac
       testpmd> start
 
@@ -104,7 +104,7 @@ Test Case 4: Multiple producers and single consumer
 
 3. Start testpmd with two ports and start forwarding::
 
-      testpmd -c 0x6 -n 4  -- -i --portmask=0x3 --txqflags=0
+      testpmd -c 0x6 -n 4  -- -i --portmask=0x3 --tx-offloads=0x8fff
       testpmd> set fwd mac
       testpmd> start
 
@@ -122,7 +122,7 @@ Test Case 4: Stack mempool handler
 
 3. Start testpmd with two ports and start forwarding::
 
-      testpmd -c 0x6 -n 4  -- -i --portmask=0x3 --txqflags=0
+      testpmd -c 0x6 -n 4  -- -i --portmask=0x3 --tx-offloads=0x8fff
       testpmd> set fwd mac
       testpmd> start
 
diff --git a/test_plans/fortville_rss_granularity_config_test_plan.rst b/test_plans/fortville_rss_granularity_config_test_plan.rst
index bc7adfd..4666d9c 100644
--- a/test_plans/fortville_rss_granularity_config_test_plan.rst
+++ b/test_plans/fortville_rss_granularity_config_test_plan.rst
@@ -77,7 +77,7 @@ Test Case 1: test with flow type ipv4-tcp
 
    1. set up testpmd with Fortville NICs::
 
-         ./testpmd -c 0x1ffff -n 4 -- -i --coremask=0x1fffe --portmask=0x3  --rxq=16 --txq=16 --txqflags=0
+         ./testpmd -c 0x1ffff -n 4 -- -i --coremask=0x1fffe --portmask=0x3  --rxq=16 --txq=16 --tx-offloads=0x8fff
 
    2. Reta Configuration(optional, if not set, will use default)::
 
@@ -152,7 +152,7 @@ Test Case 2: test with flow type ipv4-udp
 
    1. set up testpmd with Fortville NICs::
 
-         ./testpmd -c 0x1ffff -n 4 -- -i --coremask=0x1fffe --portmask=0x3  --rxq=16 --txq=16 --txqflags=0
+         ./testpmd -c 0x1ffff -n 4 -- -i --coremask=0x1fffe --portmask=0x3  --rxq=16 --txq=16 --tx-offloads=0x8fff
 
    2. Reta Configuration(optional, if not set, will use default)::
 
@@ -248,7 +248,7 @@ Test Case 5: test dual vlan(QinQ)
 
    1. set up testpmd with Fortville NICs::
 
-         ./testpmd -c 0x1ffff -n 4 -- -i --coremask=0x1fffe --portmask=0x3  --rxq=16 --txq=16 --txqflags=0
+         ./testpmd -c 0x1ffff -n 4 -- -i --coremask=0x1fffe --portmask=0x3  --rxq=16 --txq=16 --tx-offloads=0x8fff
 
    2. set qinq on::
 
@@ -311,7 +311,7 @@ Test Case 6: 32-bit GRE keys and 24-bit GRE keys test
 
    1. set up testpmd with Fortville NICs::
 
-         ./testpmd -c 0x1ffff -n 4 -- -i --coremask=0x1fffe --portmask=0x3  --rxq=16 --txq=16 --txqflags=0
+         ./testpmd -c 0x1ffff -n 4 -- -i --coremask=0x1fffe --portmask=0x3  --rxq=16 --txq=16 --tx-offloads=0x8fff
 
    2. Reta Configuration(optional, if not set, will use default)::
 
diff --git a/test_plans/generic_flow_api_test_plan.rst b/test_plans/generic_flow_api_test_plan.rst
index f7ce61e..f53e7c7 100644
--- a/test_plans/generic_flow_api_test_plan.rst
+++ b/test_plans/generic_flow_api_test_plan.rst
@@ -450,7 +450,7 @@ Test case: Fortville tunnel vxlan
 
 1. Launch the app ``testpmd`` with the following arguments::
 
-    ./x86_64-native-linuxapp-gcc/app/testpmd -c 1ffff -n 4 -w 05:00.0 --file-prefix=pf --socket-mem=1024,1024 -- -i --rxq=16 --txq=16 --txqflags=0x0 --disable-rss
+    ./x86_64-native-linuxapp-gcc/app/testpmd -c 1ffff -n 4 -w 05:00.0 --file-prefix=pf --socket-mem=1024,1024 -- -i --rxq=16 --txq=16 --tx-offloads=0x8fff --disable-rss
     testpmd> rx_vxlan_port add 4789 0
     testpmd> set fwd rxonly
     testpmd> set verbose 1
@@ -458,7 +458,7 @@ Test case: Fortville tunnel vxlan
     testpmd> start
     the pf's mac address is 00:00:00:00:01:00
 
-    ./x86_64-native-linuxapp-gcc/app/testpmd -c 1e0000 -n 4 -w 05:02.0 --file-prefix=vf --socket-mem=1024,1024 -- -i --rxq=4 --txq=4 --txqflags=0x0 --disable-rss
+    ./x86_64-native-linuxapp-gcc/app/testpmd -c 1e0000 -n 4 -w 05:02.0 --file-prefix=vf --socket-mem=1024,1024 -- -i --rxq=4 --txq=4 --tx-offloads=0x8fff --disable-rss
     testpmd> set fwd rxonly
     testpmd> set verbose 1
     testpmd> set promisc all off
@@ -553,19 +553,19 @@ Test case: Fortville tunnel nvgre
 
 1. Launch the app ``testpmd`` with the following arguments::
 
-    ./x86_64-native-linuxapp-gcc/app/testpmd -c 1ffff -n 4 -w 05:00.0 --file-prefix=pf --socket-mem=1024,1024 -- -i --rxq=16 --txq=16 --txqflags=0x0
+    ./x86_64-native-linuxapp-gcc/app/testpmd -c 1ffff -n 4 -w 05:00.0 --file-prefix=pf --socket-mem=1024,1024 -- -i --rxq=16 --txq=16 --tx-offloads=0x8fff
     testpmd> set fwd rxonly
     testpmd> set verbose 1
     testpmd> set promisc all off
     testpmd> start
 
-    ./x86_64-native-linuxapp-gcc/app/testpmd -c 1e0000 -n 4 -w 05:02.0 --file-prefix=vf0 --socket-mem=1024,1024 -- -i --rxq=4 --txq=4 --txqflags=0x0
+    ./x86_64-native-linuxapp-gcc/app/testpmd -c 1e0000 -n 4 -w 05:02.0 --file-prefix=vf0 --socket-mem=1024,1024 -- -i --rxq=4 --txq=4 --tx-offloads=0x8fff
     testpmd> set fwd rxonly
     testpmd> set verbose 1
     testpmd> set promisc all off
     testpmd> start
 
-    ./x86_64-native-linuxapp-gcc/app/testpmd -c 1e00000 -n 4 -w 05:02.1 --file-prefix=vf1 --socket-mem=1024,1024 -- -i --rxq=4 --txq=4 --txqflags=0x0
+    ./x86_64-native-linuxapp-gcc/app/testpmd -c 1e00000 -n 4 -w 05:02.1 --file-prefix=vf1 --socket-mem=1024,1024 -- -i --rxq=4 --txq=4 --tx-offloads=0x8fff
     testpmd> set fwd rxonly
     testpmd> set verbose 1
     testpmd> set promisc all off
diff --git a/test_plans/ipgre_test_plan.rst b/test_plans/ipgre_test_plan.rst
index 48adff1..3ca9af7 100644
--- a/test_plans/ipgre_test_plan.rst
+++ b/test_plans/ipgre_test_plan.rst
@@ -48,7 +48,7 @@ Test Case 1: GRE ipv4 packet detect
 
 Start testpmd and enable rxonly forwarding mode::
 
-    testpmd -c ffff -n 4 -- -i --txqflags=0x0
+    testpmd -c ffff -n 4 -- -i --tx-offloads=0x8fff
     testpmd> set fwd rxonly
     testpmd> set verbose 1
     testpmd> start
@@ -77,7 +77,7 @@ Test Case 2: GRE ipv6 packet detect
 
 Start testpmd and enable rxonly forwarding mode::
 
-    testpmd -c ffff -n 4 -- -i --txqflags=0x0
+    testpmd -c ffff -n 4 -- -i --tx-offloads=0x8fff
     testpmd> set fwd rxonly
     testpmd> set verbose 1
     testpmd> start
@@ -124,7 +124,7 @@ Test Case 3: GRE packet filter
 
 Start testpmd with multi queues::
 
-    testpmd -c ff -n 3 -- -i  --rxq=4 --txq=4 --txqflags=0x0
+    testpmd -c ff -n 3 -- -i  --rxq=4 --txq=4 --tx-offloads=0x8fff
     testpmd> set fwd rxonly
     testpmd> set nbcore 4
     testpmd> set verbose 1
@@ -161,7 +161,7 @@ Test Case 4: GRE packet chksum offload
 
 Start testpmd with hardware checksum offload enabled::
 
-    testpmd -c ff -n 3 -- -i --txqflags=0x0 --enable-rx-cksum  --port-topology=loop
+    testpmd -c ff -n 3 -- -i --tx-offloads=0x8fff --enable-rx-cksum  --port-topology=loop
     testpmd> set verbose 1
     testpmd> set fwd csum
     testpmd> csum set ip hw 0
diff --git a/test_plans/macsec_for_ixgbe_test_plan.rst b/test_plans/macsec_for_ixgbe_test_plan.rst
index 401723e..4b8a762 100644
--- a/test_plans/macsec_for_ixgbe_test_plan.rst
+++ b/test_plans/macsec_for_ixgbe_test_plan.rst
@@ -135,7 +135,7 @@ Test Case 1: MACsec packets send and receive
    1. Start the testpmd of tx port::
 
          ./testpmd -c 0x30 --socket-mem 1024,1024 --file-prefix=tx -w 0000:07:00.0 \
-         -- --port-topology=chained -i --crc-strip --txqflags=0x0
+         -- --port-topology=chained -i --crc-strip --tx-offloads=0x8fff
 
    2. Set MACsec offload on::
 
@@ -294,7 +294,7 @@ Test Case 4: normal packet send and MACsec receive
 Test Case 5: MACsec send and receive with wrong parameters
 ==========================================================
 
-1. Don't add "--txqflags=0x0" in the tx_port command line.
+1. Don't add "--tx-offloads=0x8fff" in the tx_port command line.
    the MACsec offload can't work. The tx packets are normal packets.
 
 2. Set different pn on rx and tx port, then start the data transfer.
@@ -347,7 +347,7 @@ Test Case 6: performance test of MACsec offload packets
    MACsec offload on, set fwd mac::
 
      ./x86_64-native-linuxapp-gcc/app/testpmd -c 0xc -- -i \
-     --port-topology=chained --crc-strip --txqflags=0x0
+     --port-topology=chained --crc-strip --tx-offloads=0x8fff
 
    on IXIA side, start IXIA port6 transmit, start the IXIA capture.
    view the IXIA port5 captured packet, the protocol is MACsec, the EtherType
@@ -363,7 +363,7 @@ Test Case 6: performance test of MACsec offload packets
    start two testpmd::
 
          ./testpmd -c 0x3 --socket-mem 1024,1024 --file-prefix=rx -w 0000:07:00.1 \
-         -- --port-topology=chained -i --crc-strip --txqflags=0x0
+         -- --port-topology=chained -i --crc-strip --tx-offloads=0x8fff
 
          testpmd>set macsec offload 0 on encrypt on replay-protect on
          testpmd>set macsec sc rx 0 00:00:00:00:00:01 0
@@ -373,7 +373,7 @@ Test Case 6: performance test of MACsec offload packets
          testpmd>set fwd rxonly
 
          ./testpmd -c 0xc --socket-mem 1024,1024 --file-prefix=tx -b 0000:07:00.1 \
-         -- --port-topology=chained -i --crc-strip --txqflags=0x0
+         -- --port-topology=chained -i --crc-strip --tx-offloads=0x8fff
 
          testpmd>set macsec offload 1 on encrypt on replay-protect on
          testpmd>set macsec sc rx 1 00:00:00:00:00:02 0
diff --git a/test_plans/pmd_bonded_test_plan.rst b/test_plans/pmd_bonded_test_plan.rst
index ce12014..846ed62 100644
--- a/test_plans/pmd_bonded_test_plan.rst
+++ b/test_plans/pmd_bonded_test_plan.rst
@@ -447,7 +447,7 @@ Bi-directional flow: Use IXIA to generate traffic to non bonded eth dev(port3) a
 
 Try to check that if port0 is link down, port1 can be backup quickly and re-check the performance at port1 and port3's mapped IXIA ports' RX::
 
-    ./app/testpmd -c f -n 4 -- -i --burst=32 --rxfreet=32 --mbcache=250 --txpt=32 --rxht=8 --rxwt=0 --txfreet=32 --txrst=32 --txqflags=0xf01
+    ./app/testpmd -c f -n 4 -- -i --burst=32 --rxfreet=32 --mbcache=250 --txpt=32 --rxht=8 --rxwt=0 --txfreet=32 --txrst=32 --tx-offloads=0x0
     testpmd> create bonded device 1 0
     testpmd> add bonding slave 0 4
     testpmd> add bonding slave 1 4
diff --git a/test_plans/pmdrss_hash_test_plan.rst b/test_plans/pmdrss_hash_test_plan.rst
index 932a709..0e6aa20 100644
--- a/test_plans/pmdrss_hash_test_plan.rst
+++ b/test_plans/pmdrss_hash_test_plan.rst
@@ -156,7 +156,7 @@ This case test bond slaves will auto sync rss hash config, it only support by fo
 
 #. set up testpmd with fortville NICs::
 
-      ./testpmd -c f -n 4 -- -i --portmask 0x3 --txqflags=0
+      ./testpmd -c f -n 4 -- -i --portmask 0x3 --tx-offloads=0x8fff
 
 #. create bond device with mode 3::
 
diff --git a/test_plans/qinq_filter_test_plan.rst b/test_plans/qinq_filter_test_plan.rst
index e180341..10f697c 100644
--- a/test_plans/qinq_filter_test_plan.rst
+++ b/test_plans/qinq_filter_test_plan.rst
@@ -56,7 +56,7 @@ Testpmd configuration - 4 RX/TX queues per port
 
 #. set up testpmd with fortville NICs::
 
-    ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x1f -n 4 -- -i --rxq=4 --txq=4 --txqflags=0x0  --disable-rss
+    ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x1f -n 4 -- -i --rxq=4 --txq=4 --tx-offloads=0x8fff  --disable-rss
 
 #. enable qinq::
 
@@ -89,7 +89,7 @@ Testpmd configuration - 4 RX/TX queues per port
 
 #. set up testpmd with fortville NICs::
 
-    ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x1f -n 4 -- -i --rxq=4 --txq=4 --txqflags=0x0  --disable-rss
+    ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x1f -n 4 -- -i --rxq=4 --txq=4 --tx-offloads=0x8fff  --disable-rss
 
 #. enable qinq::
 
@@ -132,7 +132,7 @@ Test Case 3: qinq packet filter to VF queues
  
 #. set up testpmd with fortville PF NICs::
 
-    ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x1f -n 4 --socket-mem=1024,1024 --file-prefix=pf -w 81:00.0 -- -i --rxq=4 --txq=4 --txqflags=0x0
+    ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x1f -n 4 --socket-mem=1024,1024 --file-prefix=pf -w 81:00.0 -- -i --rxq=4 --txq=4 --tx-offloads=0x8fff
 
 #. enable qinq::
 
@@ -209,7 +209,7 @@ Test Case 4: qinq packet filter with diffierent tpid
  
 #. set up testpmd with fortville PF NICs::
 
-    ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x1f -n 4 --socket-mem=1024,1024 --file-prefix=pf -w 81:00.0 -- -i --rxq=4 --txq=4 --txqflags=0x0
+    ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x1f -n 4 --socket-mem=1024,1024 --file-prefix=pf -w 81:00.0 -- -i --rxq=4 --txq=4 --tx-offloads=0x8fff
 
 #. enable qinq::
 
diff --git a/test_plans/tx_preparation_test_plan.rst b/test_plans/tx_preparation_test_plan.rst
index e4b6b7d..978c7e6 100644
--- a/test_plans/tx_preparation_test_plan.rst
+++ b/test_plans/tx_preparation_test_plan.rst
@@ -72,11 +72,11 @@ Change mtu for large packet::
 
    ifconfig eth1 mtu 9000
 
-Launch the ``testpmd`` with the following arguments, set ``--txqflags=0`` to
+Launch the ``testpmd`` with the following arguments, set ``--tx-offloads=0x8fff`` to
 let TX checksum offloads, TSO mode in the “Full Featured” TX path, add
 --max-pkt-len for large packet::
 
-   ./testpmd -c 0x6 -n 4  -- -i --txqflags=0 --port-topology=chained
+   ./testpmd -c 0x6 -n 4  -- -i --tx-offloads=0x8fff --port-topology=chained
    --max-pkt-len=9000
 
 Set the ``csum`` forwarding mode::
diff --git a/test_plans/uni_pkt_test_plan.rst b/test_plans/uni_pkt_test_plan.rst
index 6ff76d0..6db91b0 100644
--- a/test_plans/uni_pkt_test_plan.rst
+++ b/test_plans/uni_pkt_test_plan.rst
@@ -55,7 +55,7 @@ Plug in three different types of nic on the board.
 
 Start testpmd and then enable rxonly and verbose mode::
 
-    ./x86_64-native-linuxapp-gcc/app/testpmd -c f -n 4 -- -i --txqflags=0x0
+    ./x86_64-native-linuxapp-gcc/app/testpmd -c f -n 4 -- -i --tx-offloads=0x8fff
     set fwd rxonly
     set verbose 1
     start
diff --git a/test_plans/vf_daemon_test_plan.rst b/test_plans/vf_daemon_test_plan.rst
index cc76d75..5dd582b 100644
--- a/test_plans/vf_daemon_test_plan.rst
+++ b/test_plans/vf_daemon_test_plan.rst
@@ -87,7 +87,7 @@ Prerequisites
 
 5. Start testpmd on host and vm0 in chained port topology::
 
-        ./testpmd -c f -n 4 -- -i --port-topology=chained --txqflags=0
+        ./testpmd -c f -n 4 -- -i --port-topology=chained --tx-offloads=0x8fff
 
 
 Test Case 1: Set VLAN insert for VF from PF
diff --git a/test_plans/vf_jumboframe_test_plan.rst b/test_plans/vf_jumboframe_test_plan.rst
index 8b048f5..2f4cae3 100644
--- a/test_plans/vf_jumboframe_test_plan.rst
+++ b/test_plans/vf_jumboframe_test_plan.rst
@@ -86,7 +86,7 @@ Prerequisites
 5. Start testpmd, set it in mac forward mode::
 
       testpmd -c 0x0f-- -i --portmask=0x1 \
-        --txqflags=0 --max-pkt-len=9000--port-topology=loop
+        --tx-offloads=0x8fff --max-pkt-len=9000--port-topology=loop
       testpmd> set fwd mac
       testpmd> start
 
diff --git a/test_plans/vf_macfilter_test_plan.rst b/test_plans/vf_macfilter_test_plan.rst
index e8c67a7..221c05e 100644
--- a/test_plans/vf_macfilter_test_plan.rst
+++ b/test_plans/vf_macfilter_test_plan.rst
@@ -97,7 +97,7 @@ Test Case 1: test_kernel_2pf_2vf_1vm_iplink_macfilter
    disable promisc mode,set it in mac forward mode::
 
       ./tools/dpdk_nic_bind.py --bind=igb_uio 00:06.0 00:07.0
-      ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x0f -n 4 -w 00:06.0 -w 00:07.0 -- -i --portmask=0x3 --txqflags=0
+      ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x0f -n 4 -w 00:06.0 -w 00:07.0 -- -i --portmask=0x3 --tx-offloads=0x8fff
 
       testpmd> port stop all
       testpmd> port config all crc-strip on
@@ -175,7 +175,7 @@ Test Case 2: test_kernel_2pf_2vf_1vm_mac_add_filter
    VF, disable promisc mode, add a new MAC to VF0 and then start::
 
       ./tools/dpdk_nic_bind.py --bind=igb_uio 00:06.0 00:07.0
-      ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x0f -n 4 -w 00:06.0 -w 00:07.0 -- -i --portmask=0x3 --txqflags=0
+      ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x0f -n 4 -w 00:06.0 -w 00:07.0 -- -i --portmask=0x3 --tx-offloads=0x8fff
 
       testpmd> port stop all
       testpmd> port config all crc-strip on
diff --git a/test_plans/vf_packet_rxtx_test_plan.rst b/test_plans/vf_packet_rxtx_test_plan.rst
index c28c665..0df9984 100644
--- a/test_plans/vf_packet_rxtx_test_plan.rst
+++ b/test_plans/vf_packet_rxtx_test_plan.rst
@@ -97,7 +97,7 @@ Test Case 1: VF_packet_IO_kernel_PF_dpdk_VF
 
       ./tools/dpdk_nic_bind.py --bind=igb_uio 00:06.0 00:07.0
       ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x0f -n 4 -w 00:06.0 -w 00:07.0 \
-                                               -- -i --portmask=0x3 --txqflags=0
+                                               -- -i --portmask=0x3 --tx-offloads=0x8fff
 
       testpmd> set fwd mac
       testpmd> start
diff --git a/test_plans/vf_pf_reset_test_plan.rst b/test_plans/vf_pf_reset_test_plan.rst
index f59ab81..7d526c8 100644
--- a/test_plans/vf_pf_reset_test_plan.rst
+++ b/test_plans/vf_pf_reset_test_plan.rst
@@ -85,7 +85,7 @@ Test Case 1: vf reset -- create two vfs on one pf
 5. Run testpmd::
 
      ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x0f -n 4 -- -i \
-     --portmask=0x3 --txqflags=0 --crc-strip
+     --portmask=0x3 --tx-offloads=0x8fff --crc-strip
      testpmd> set fwd mac
      testpmd> start
      testpmd> set allmulti all on
@@ -203,7 +203,7 @@ Test Case 3: vf reset -- create one vf on each pf
 3. Start one testpmd on two vf ports::
 
      ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x0f -n 4 -- -i \
-     --portmask=0x3 --txqflags=0 --crc-strip
+     --portmask=0x3 --tx-offloads=0x8fff --crc-strip
 
 4. Start forwarding::
 
@@ -230,7 +230,7 @@ Test Case 4: vlan rx restore -- vf reset all ports
 1. Execute the step1-step3 of test case 1, then start the testpmd::
 
      ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x0f -n 4 -- -i \
-     --portmask=0x3 --txqflags=0 --crc-strip
+     --portmask=0x3 --tx-offloads=0x8fff --crc-strip
      testpmd> set fwd mac
 
 2. Add vlan on both ports::
@@ -283,7 +283,7 @@ test Case 5: vlan rx restore -- vf reset one port
 1. Execute the step1-step3 of test case 1, then start the testpmd::
 
      ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x0f -n 4 -- -i  \
-     --portmask=0x3 --txqflags=0 --crc-strip
+     --portmask=0x3 --tx-offloads=0x8fff --crc-strip
      testpmd> set fwd mac
 
 2. Add vlan on both ports::
@@ -413,7 +413,7 @@ Test Case 7: vlan tx restore
 2. Run testpmd::
 
      ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x0f -n 4 -- -i \
-     --portmask=0x3 --txqflags=0 --crc-strip
+     --portmask=0x3 --tx-offloads=0x8fff --crc-strip
 
 2. Add tx vlan offload on VF1 port, take care the first param is port,
    start forwarding::
@@ -457,7 +457,7 @@ test Case 8: MAC address restore
 3. Start testpmd on two vf ports::
 
      ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x0f -n 4  \
-     -- -i --portmask=0x3 --txqflags=0 --crc-strip
+     -- -i --portmask=0x3 --tx-offloads=0x8fff --crc-strip
 
 4. Add MAC address to the vf0 ports::
 
@@ -527,7 +527,7 @@ test Case 9: vf reset (two vfs passed through to one VM)
 
      ./tools/dpdk_nic_bind.py --bind=igb_uio 00:05.0 00:05.1
      ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x0f -n 4 \
-     -w 00:05.0 -w 00:05.1 -- -i --portmask=0x3 --txqflags=0
+     -w 00:05.0 -w 00:05.1 -- -i --portmask=0x3 --tx-offloads=0x8fff
 
 5. Add MAC address to the vf0 ports, set it in mac forward mode::
 
diff --git a/test_plans/vf_rss_test_plan.rst b/test_plans/vf_rss_test_plan.rst
index d1e5e9d..c425227 100644
--- a/test_plans/vf_rss_test_plan.rst
+++ b/test_plans/vf_rss_test_plan.rst
@@ -88,7 +88,7 @@ Testpmd configuration - 4 RX/TX queues per port
 
 ::
 
-  testpmd -c 1f -n 3  -- -i --rxq=4 --txq=4 --txqflags=0
+  testpmd -c 1f -n 3  -- -i --rxq=4 --txq=4 --tx-offloads=0x8fff
 
 Testpmd Configuration Options
 -----------------------------
diff --git a/test_plans/vf_to_vf_nic_bridge_test_plan.rst b/test_plans/vf_to_vf_nic_bridge_test_plan.rst
index 08c0614..576c9d7 100644
--- a/test_plans/vf_to_vf_nic_bridge_test_plan.rst
+++ b/test_plans/vf_to_vf_nic_bridge_test_plan.rst
@@ -107,7 +107,7 @@ dpdk pktgen to vf in vm0, and verify the vf on vm0 can receive stream.
 
 Step 1: run testpmd on vm0::
 
-        ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x7 -n 1  -- -i  --txqflags=0
+        ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x7 -n 1  -- -i  --tx-offloads=0x8fff
 
 Step 2: set rxonly and start on vm0::
 
@@ -164,7 +164,7 @@ Test Case3: test_2vf_k2d_scapy_stream
 
 Step 1: run testpmd on vm0::
 
-        ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x7 -n 1  -- -i  --txqflags=0
+        ./x86_64-native-linuxapp-gcc/app/testpmd -c 0x7 -n 1  -- -i  --tx-offloads=0x8fff
 
 Step 2: set rxonly and start on vm0::
 
diff --git a/test_plans/vf_vlan_test_plan.rst b/test_plans/vf_vlan_test_plan.rst
index a80e506..49d7c37 100644
--- a/test_plans/vf_vlan_test_plan.rst
+++ b/test_plans/vf_vlan_test_plan.rst
@@ -87,7 +87,7 @@ Prerequisites
 
 5. Start testpmd, set it in rxonly mode and enable verbose output::
 
-     testpmd -c 0x0f -n 4 -w 00:04.0 -w 00:05.0 -- -i --portmask=0x3 --txqflags=0
+     testpmd -c 0x0f -n 4 -w 00:04.0 -w 00:05.0 -- -i --portmask=0x3 --tx-offloads=0x8fff
      testpmd> set fwd rxonly
      testpmd> set verbose 1
      testpmd> start
@@ -148,7 +148,7 @@ Test Case 3: VF tagged vlan tx
 
 1. Start testpmd with full-featured tx code path and with mac forward mode::
 
-     testpmd -c f -n 3 -- -i --txqflags=0x0
+     testpmd -c f -n 3 -- -i --tx-offloads=0x8fff
      testpmd> set fwd mac
      testpmd> start
 
diff --git a/test_plans/virtio_1.0_test_plan.rst b/test_plans/virtio_1.0_test_plan.rst
index 596702a..8643e76 100644
--- a/test_plans/virtio_1.0_test_plan.rst
+++ b/test_plans/virtio_1.0_test_plan.rst
@@ -38,12 +38,12 @@ Virtio 1.0 is a new version of virtio. And the virtio 1.0 spec link is at
 http://docs.oasis-open.org/virtio/virtio/v1.0/virtio-v1.0.pdf.
 
 The major difference is at PCI layout. For testing virtio 1.0 pmd, we need
-test the basic RX/TX, different path(txqflags), mergeable on/off, and also
+test the basic RX/TX, different path(tx-offloads), mergeable on/off, and also
 test with virtio0.95 to ensure they can co-exist. Besides, we need test virtio
 1.0's performance to ensure it has similar performance as virtio0.95.
 
 
-Test Case 1: test_func_vhost_user_virtio1.0-pmd with different txqflags
+Test Case 1: test_func_vhost_user_virtio1.0-pmd with different tx-offloads
 =======================================================================
 
 Note: For virtio1.0 usage, we need use qemu version >2.4, such as 2.4.1 or 2.5.0.
@@ -67,7 +67,7 @@ Note: For virtio1.0 usage, we need use qemu version >2.4, such as 2.4.1 or 2.5.0
 
      ./<dpdk_folder>/tools/dpdk_nic_bind.py --bind igb_uio 00:03.0
 
-     ./<dpdk_folder>/x86_64-native-linuxapp-gcc/app/test-pmd/testpmd -c 0x3 -n 4 -- -i --txqflags 0x0f00 --disable-hw-vlan
+     ./<dpdk_folder>/x86_64-native-linuxapp-gcc/app/test-pmd/testpmd -c 0x3 -n 4 -- -i --tx-offloads=0x8000 --disable-hw-vlan
 
      $ >set fwd mac
 
@@ -91,11 +91,11 @@ Note: For virtio1.0 usage, we need use qemu version >2.4, such as 2.4.1 or 2.5.0
 
 4. Send traffic to virtio1(MAC1=52:54:00:00:00:01) with VLAN ID=1000. Check if virtio packet can be RX/TX and also check the TX packet size is same as the RX packet size.
 
-5. Also run the dpdk testpmd in VM with txqflags=0xf01 for the virtio pmd optimization usage::
+5. Also run the dpdk testpmd in VM with tx-offloads=0 for the virtio pmd optimization usage::
 
      ./<dpdk_folder>/tools/dpdk_nic_bind.py --bind igb_uio 00:03.0
 
-     ./<dpdk_folder>/x86_64-native-linuxapp-gcc/app/test-pmd/testpmd -c 0x3 -n 4 -- -i --txqflags=0x0f01 --disable-hw-vlan
+     ./<dpdk_folder>/x86_64-native-linuxapp-gcc/app/test-pmd/testpmd -c 0x3 -n 4 -- -i --tx-offloads=0 --disable-hw-vlan
 
      $ >set fwd mac
 
@@ -127,7 +127,7 @@ Note: For virtio1.0 usage, we need use qemu version >2.4, such as 2.4.1 or 2.5.0
 
      ./<dpdk_folder>/tools/dpdk_nic_bind.py --bind igb_uio 00:03.0
 
-     ./<dpdk_folder>/x86_64-native-linuxapp-gcc/app/test-pmd/testpmd -c 0x3 -n 4 -- -i --txqflags 0x0f00 --disable-hw-vlan
+     ./<dpdk_folder>/x86_64-native-linuxapp-gcc/app/test-pmd/testpmd -c 0x3 -n 4 -- -i --tx-offloads=0x8000 --disable-hw-vlan
 
      $ >set fwd mac
 
@@ -174,7 +174,7 @@ Test Case 3: test_func_vhost_user_virtio1.0-pmd with mergeable enabled
 
      ./<dpdk_folder>/tools/dpdk_nic_bind.py --bind igb_uio 00:03.0
 
-     ./<dpdk_folder>/x86_64-native-linuxapp-gcc/app/test-pmd/testpmd -c 0x3 -n 4 -- -i --txqflags 0x0f00 --disable-hw-vlan --max-pkt-len=9000
+     ./<dpdk_folder>/x86_64-native-linuxapp-gcc/app/test-pmd/testpmd -c 0x3 -n 4 -- -i --tx-offloads=0x8000 --disable-hw-vlan --max-pkt-len=9000
 
      $ >set fwd mac
 
@@ -216,7 +216,7 @@ Test Case 4: test_func_vhost_user_one-vm-virtio1.0-one-vm-virtio0.95
 
      ./<dpdk_folder>/tools/dpdk_nic_bind.py --bind igb_uio 00:03.0
 
-     ./<dpdk_folder>/x86_64-native-linuxapp-gcc/app/test-pmd/testpmd -c 0x3 -n 4 -- -i --txqflags 0x0f00 --disable-hw-vlan --eth-peer=0,52:54:00:00:00:02
+     ./<dpdk_folder>/x86_64-native-linuxapp-gcc/app/test-pmd/testpmd -c 0x3 -n 4 -- -i --tx-offloads=0x8000 --disable-hw-vlan --eth-peer=0,52:54:00:00:00:02
 
      $ >set fwd mac
 
@@ -226,7 +226,7 @@ Test Case 4: test_func_vhost_user_one-vm-virtio1.0-one-vm-virtio0.95
 
      ./<dpdk_folder>/tools/dpdk_nic_bind.py --bind igb_uio 00:03.0
 
-     ./<dpdk_folder>/x86_64-native-linuxapp-gcc/app/test-pmd/testpmd -c 0x3 -n 4 -- -i --txqflags 0x0f00 --disable-hw-vlan
+     ./<dpdk_folder>/x86_64-native-linuxapp-gcc/app/test-pmd/testpmd -c 0x3 -n 4 -- -i --tx-offloads=0x8000 --disable-hw-vlan
 
      $ >set fwd mac
 
@@ -258,7 +258,7 @@ Note: For virtio1.0 usage, we need use qemu version >2.4, such as 2.4.1 or 2.5.0
 
      ./<dpdk_folder>/tools/dpdk_nic_bind.py --bind igb_uio 00:03.0
 
-     ./<dpdk_folder>/x86_64-native-linuxapp-gcc/app/test-pmd/testpmd -c 0x3 -n 4 -- -i --txqflags 0x0f00 --disable-hw-vlan
+     ./<dpdk_folder>/x86_64-native-linuxapp-gcc/app/test-pmd/testpmd -c 0x3 -n 4 -- -i --tx-offloads=0x8000 --disable-hw-vlan
 
      $ >set fwd mac
 
diff --git a/test_plans/vlan_ethertype_config_test_plan.rst b/test_plans/vlan_ethertype_config_test_plan.rst
index 70faf31..9315e39 100644
--- a/test_plans/vlan_ethertype_config_test_plan.rst
+++ b/test_plans/vlan_ethertype_config_test_plan.rst
@@ -60,7 +60,7 @@ Test Case 1: change VLAN TPID
 
 1. Start testpmd, start in rxonly mode::
 
-      ./testpmd -c 0xff -n 4 -- -i --portmask=0x3 --txqflags=0
+      ./testpmd -c 0xff -n 4 -- -i --portmask=0x3 --tx-offloads=0x8fff
       testpmd> set fwd rxonly
       testpmd> set verbose 1
       testpmd> start
@@ -76,7 +76,7 @@ Test Case 2: test VLAN filtering on/off
 
 1. Start testpmd, setup vlan filter on, start in mac forwarding mode::
 
-      ./testpmd -c 0xff -n 4 -- -i --portmask=0x3 --txqflags=0
+      ./testpmd -c 0xff -n 4 -- -i --portmask=0x3 --tx-offloads=0x8fff
       testpmd> set fwd mac
       testpmd> vlan set filter on 0
       testpmd> start
@@ -96,7 +96,7 @@ Test Case 3: test adding VLAN Tag Identifier with changing VLAN TPID
 
 1. start testpmd, setup vlan filter on, start in mac forwarding mode::
 
-      ./testpmd -c 0xff -n 4 -- -i --portmask=0x3 --txqflags=0
+      ./testpmd -c 0xff -n 4 -- -i --portmask=0x3 --tx-offloads=0x8fff
       testpmd> set fwd mac
       testpmd> vlan set filter on 0
       testpmd> vlan set strip off 0
@@ -128,7 +128,7 @@ Test Case 4: test VLAN header striping with changing VLAN TPID
 
 1. start testpmd, setup vlan filter off, vlan strip on, start in mac forwarding mode::
 
-      ./testpmd -c 0xff -n 4 -- -i --portmask=0x3 --txqflags=0
+      ./testpmd -c 0xff -n 4 -- -i --portmask=0x3 --tx-offloads=0x8fff
       testpmd> set fwd mac
       testpmd> vlan set filter off 0
       testpmd> vlan set strip on 0
@@ -157,7 +157,7 @@ Test Case 5: test VLAN header inserting with changing VLAN TPID
 
 1. start testpmd, enable vlan packet forwarding, start in mac forwarding mode::
 
-      ./testpmd -c 0xff -n 4 -- -i --portmask=0x3 --txqflags=0
+      ./testpmd -c 0xff -n 4 -- -i --portmask=0x3 --tx-offloads=0x8fff
       testpmd> set fwd mac
       testpmd> vlan set filter off 0
       testpmd> vlan set strip off 0
@@ -192,7 +192,7 @@ Test Case 6: Change S-Tag and C-Tag within QinQ
 
 1. Start testpmd, enable QinQ, start in rxonly mode::
 
-      ./testpmd -c 0xff -n 4 -- -i --portmask=0x3 --txqflags=0
+      ./testpmd -c 0xff -n 4 -- -i --portmask=0x3 --tx-offloads=0x8fff
       testpmd> vlan set qinq on 0
       testpmd> set fwd rxonly
       testpmd> set verbose 1
diff --git a/test_plans/vxlan_sample_test_plan.rst b/test_plans/vxlan_sample_test_plan.rst
index b7a39ac..a092e85 100644
--- a/test_plans/vxlan_sample_test_plan.rst
+++ b/test_plans/vxlan_sample_test_plan.rst
@@ -93,7 +93,7 @@ Start virtual machine with hugepage based memory and two vhost-user devices::
 
 Login into virtual machine and start testpmd with additional arguments::
 
-    testpmd -c f -n 3 -- -i --txqflags=0xf00 --disable-hw-vlan
+    testpmd -c f -n 3 -- -i --tx-offloads=0x8000 --disable-hw-vlan
 
 Start packet forward of testpmd and transit several packets for mac learning::
 
diff --git a/test_plans/vxlan_test_plan.rst b/test_plans/vxlan_test_plan.rst
index 670ece7..c058637 100644
--- a/test_plans/vxlan_test_plan.rst
+++ b/test_plans/vxlan_test_plan.rst
@@ -58,7 +58,7 @@ Test Case: Vxlan ipv4 packet detect
 ===================================
 Start testpmd with tunneling packet type to vxlan::
 
-    testpmd -c ffff -n 4 -- -i --rxq=4 --txq=4 --nb-cores=8 --nb-ports=2 --txqflags=0x0
+    testpmd -c ffff -n 4 -- -i --rxq=4 --txq=4 --nb-cores=8 --nb-ports=2 --tx-offloads=0x8fff
 
 Set rxonly packet forwarding mode and enable verbose log::
 
@@ -91,7 +91,7 @@ Test Case: Vxlan ipv6 packet detect
 ===================================
 Start testpmd with tunneling packet type to vxlan::
 
-    testpmd -c ffff -n 4 -- -i --disable-rss --rxq=4 --txq=4 --nb-cores=8 --nb-ports=2 --txqflags=0x0
+    testpmd -c ffff -n 4 -- -i --disable-rss --rxq=4 --txq=4 --nb-cores=8 --nb-ports=2 --tx-offloads=0x8fff
 
 Set rxonly packet forwarding mode and enable verbose log::
 
@@ -124,7 +124,7 @@ Test Case: Vxlan ipv4 checksum offload
 
 Start testpmd with tunneling packet type to vxlan::
 
-    testpmd -c ffff -n 4 -- -i --rxq=4 --txq=4 --nb-cores=8 --nb-ports=2 --txqflags=0x0
+    testpmd -c ffff -n 4 -- -i --rxq=4 --txq=4 --nb-cores=8 --nb-ports=2 --tx-offloads=0x8fff
 
 Set csum packet forwarding mode and enable verbose log::
 
@@ -290,7 +290,7 @@ Test Case: Cloud Filter
 Start testpmd with tunneling packet type to vxlan and disable receive side
 scale for hardware limitation::
 
-    testpmd -c ffff -n 4 -- -i --disable-rss --rxq=4 --txq=4 --nb-cores=8 --nb-ports=2 --txqflags=0x0
+    testpmd -c ffff -n 4 -- -i --disable-rss --rxq=4 --txq=4 --nb-cores=8 --nb-ports=2 --tx-offloads=0x8fff
 
 Set rxonly packet forwarding mode and enable verbose log::
 
diff --git a/tests/TestSuite_fortville_rss_granularity_config.py b/tests/TestSuite_fortville_rss_granularity_config.py
index 665ee20..c86a20f 100644
--- a/tests/TestSuite_fortville_rss_granularity_config.py
+++ b/tests/TestSuite_fortville_rss_granularity_config.py
@@ -202,7 +202,7 @@ class TestFortvilleRssGranularityConfig(TestCase):
         # test with different rss queues
         for queue in testQueues:
             self.dut.send_expect(
-                "./%s/app/testpmd  -c fffff -n %d -- -i --coremask=0xffffe --portmask=0x3 --rxq=%d --txq=%d --txqflags=0" %
+                "./%s/app/testpmd  -c fffff -n %d -- -i --coremask=0xffffe --portmask=0x3 --rxq=%d --txq=%d --tx-offloads=0x8fff" %
                 (self.target, self.dut.get_memory_channels(), queue, queue), "testpmd> ", 120)
 
             self.dut.send_expect("set verbose 8", "testpmd> ")
@@ -278,7 +278,7 @@ class TestFortvilleRssGranularityConfig(TestCase):
         # test with different rss queues
         for queue in testQueues:
             self.dut.send_expect(
-                "./%s/app/testpmd  -c fffff -n %d -- -i --coremask=0xffffe --portmask=0x3 --rxq=%d --txq=%d --txqflags=0" %
+                "./%s/app/testpmd  -c fffff -n %d -- -i --coremask=0xffffe --portmask=0x3 --rxq=%d --txq=%d --tx-offloads=0x8fff" %
                 (self.target, self.dut.get_memory_channels(), queue, queue), "testpmd> ", 120)
 
             self.dut.send_expect("set verbose 8", "testpmd> ")
@@ -355,7 +355,7 @@ class TestFortvilleRssGranularityConfig(TestCase):
         # test with different rss queues
         for queue in testQueues:
             self.dut.send_expect(
-                "./%s/app/testpmd  -c fffff -n %d -- -i --coremask=0xffffe --portmask=0x3 --rxq=%d --txq=%d --txqflags=0" %
+                "./%s/app/testpmd  -c fffff -n %d -- -i --coremask=0xffffe --portmask=0x3 --rxq=%d --txq=%d --tx-offloads=0x8fff" %
                 (self.target, self.dut.get_memory_channels(), queue, queue), "testpmd> ", 120)
 
             self.dut.send_expect("set verbose 8", "testpmd> ")
@@ -432,7 +432,7 @@ class TestFortvilleRssGranularityConfig(TestCase):
         # test with different rss queues
         for queue in testQueues:
             self.dut.send_expect(
-                "./%s/app/testpmd  -c fffff -n %d -- -i --coremask=0xffffe --portmask=0x3 --rxq=%d --txq=%d --txqflags=0" %
+                "./%s/app/testpmd  -c fffff -n %d -- -i --coremask=0xffffe --portmask=0x3 --rxq=%d --txq=%d --tx-offloads=0x8fff" %
                 (self.target, self.dut.get_memory_channels(), queue, queue), "testpmd> ", 120)
 
             self.dut.send_expect("set verbose 8", "testpmd> ")
@@ -509,7 +509,7 @@ class TestFortvilleRssGranularityConfig(TestCase):
         # test with different rss queues
         for queue in testQueues:
             self.dut.send_expect(
-                "./%s/app/testpmd  -c fffff -n %d -- -i --coremask=0xffffe --portmask=0x3 --rxq=%d --txq=%d --txqflags=0" %
+                "./%s/app/testpmd  -c fffff -n %d -- -i --coremask=0xffffe --portmask=0x3 --rxq=%d --txq=%d --tx-offloads=0x8fff" %
                 (self.target, self.dut.get_memory_channels(), queue, queue), "testpmd> ", 120)
 
             self.dut.send_expect("set verbose 8", "testpmd> ")
@@ -570,7 +570,7 @@ class TestFortvilleRssGranularityConfig(TestCase):
         # test with different rss queues
         for queue in testQueues:
             self.dut.send_expect(
-                "./%s/app/testpmd  -c fffff -n %d -- -i --coremask=0xffffe --portmask=0x3 --rxq=%d --txq=%d --txqflags=0" %
+                "./%s/app/testpmd  -c fffff -n %d -- -i --coremask=0xffffe --portmask=0x3 --rxq=%d --txq=%d --tx-offloads=0x8fff" %
                 (self.target, self.dut.get_memory_channels(), queue, queue), "testpmd> ", 120)
 
             self.dut.send_expect("set verbose 8", "testpmd> ")
diff --git a/tests/TestSuite_ipgre.py b/tests/TestSuite_ipgre.py
index 44a5eb3..c1d052e 100644
--- a/tests/TestSuite_ipgre.py
+++ b/tests/TestSuite_ipgre.py
@@ -263,7 +263,7 @@ class TestIpgre(TestCase):
         inner_mac = "10:00:00:00:00:00"
         
         # Start testpmd with multi queues
-        #testpmd_cmd = "./%s/app/testpmd -c ff -n 3 -- -i  --rxq=4 --txq=4 --txqflags=0x0" % self.target
+        #testpmd_cmd = "./%s/app/testpmd -c ff -n 3 -- -i  --rxq=4 --txq=4 --tx-offloads=0x8fff" % self.target
         testpmd_cmd = "./%s/app/testpmd -c ff -n 3 -- -i --enable-rx-cksum  --rxq=4 --txq=4" % self.target
         self.dut.send_expect(testpmd_cmd, "testpmd>", 20)
         self.dut.send_expect("set fwd rxonly", "testpmd>")
@@ -307,7 +307,7 @@ class TestIpgre(TestCase):
         Send packet with wrong IP/TCP/UDP/SCTP checksum and check forwarded packet checksum 
         """
         # Start testpmd and enable rxonly forwarding mode
-        testpmd_cmd = "./%s/app/testpmd -c ff -n 3 -- -i --enable-rx-cksum --txqflags=0x0 --port-topology=loop" % self.target
+        testpmd_cmd = "./%s/app/testpmd -c ff -n 3 -- -i --enable-rx-cksum --tx-offloads=0x8fff --port-topology=loop" % self.target
         self.dut.send_expect(testpmd_cmd, "testpmd>", 20)
         self.dut.send_expect("set verbose 1", "testpmd>")
         self.dut.send_expect("set fwd csum", "testpmd>")
diff --git a/tests/TestSuite_nvgre.py b/tests/TestSuite_nvgre.py
index 3a01920..4cb3e8f 100644
--- a/tests/TestSuite_nvgre.py
+++ b/tests/TestSuite_nvgre.py
@@ -438,7 +438,7 @@ class TestNvgre(TestCase):
         """
         send nvgre packet and check whether testpmd detect the correct packet type
         """
-        out = self.dut.send_expect("./%s/app/testpmd -c %s -n %d -- -i --disable-rss --rxq=4 --txq=4 --nb-cores=4 --portmask=%s --txqflags=0"
+        out = self.dut.send_expect("./%s/app/testpmd -c %s -n %d -- -i --disable-rss --rxq=4 --txq=4 --nb-cores=4 --portmask=%s --tx-offloads=0x8fff"
                                    % (self.target, self.coremask, self.dut.get_memory_channels(), self.portmask), "testpmd>", 30)
         out = self.dut.send_expect("set fwd rxonly", "testpmd>", 10)
         self.dut.send_expect("set verbose 1", "testpmd>", 10)
@@ -467,7 +467,7 @@ class TestNvgre(TestCase):
         """
         send nvgre packet and check whether receive packet in assigned queue
         """
-        self.dut.send_expect("./%s/app/testpmd -c %s -n %d -- -i --disable-rss --rxq=4 --txq=4 --nb-cores=4 --portmask=%s --txqflags=0"
+        self.dut.send_expect("./%s/app/testpmd -c %s -n %d -- -i --disable-rss --rxq=4 --txq=4 --nb-cores=4 --portmask=%s --tx-offloads=0x8fff"
                              % (self.target, self.coremask, self.dut.get_memory_channels(), self.portmask), "testpmd>", 30)
         self.dut.send_expect("set fwd rxonly", "testpmd>", 10)
         self.dut.send_expect("set verbose 1", "testpmd>", 10)
@@ -543,7 +543,7 @@ class TestNvgre(TestCase):
         self.logger.info("chksums_ref:" + str(chksums_default))
 
         # start testpmd with 2queue/1port
-        out = self.dut.send_expect("./%s/app/testpmd -c %s -n %d -- -i --disable-rss --rxq=4 --txq=4 --nb-cores=4 --portmask=%s --enable-rx-cksum --txqflags=0"
+        out = self.dut.send_expect("./%s/app/testpmd -c %s -n %d -- -i --disable-rss --rxq=4 --txq=4 --nb-cores=4 --portmask=%s --enable-rx-cksum --tx-offloads=0x8fff"
                                    % (self.target, self.coremask, self.dut.get_memory_channels(), self.portmask), "testpmd>", 30)
         # disable vlan filter
         self.dut.send_expect('vlan set filter off %d' % self.dut_rx_port, "testpmd")
@@ -664,7 +664,7 @@ class TestNvgre(TestCase):
         self.nvgre_filter(filter_type="imac", remove=True)
         config = NvgreTestConfig(self)
         # config.outer_mac_dst = self.dut_port_mac
-        self.dut.send_expect("./%s/app/testpmd -c %s -n %d -- -i --disable-rss --rxq=4 --txq=4 --nb-cores=4 --portmask=%s --txqflags=0"
+        self.dut.send_expect("./%s/app/testpmd -c %s -n %d -- -i --disable-rss --rxq=4 --txq=4 --nb-cores=4 --portmask=%s --tx-offloads=0x8fff"
                              % (self.target, self.coremask, self.dut.get_memory_channels(), self.portmask), "testpmd>", 30)
         out = self.dut.send_expect("tunnel_filter add %d %s %s %s %d nvgre %s %d %d"
                                    % (self.dut_rx_port, config.outer_mac_dst, self.invalid_mac, config.inner_ip_dst, vlan_id,
diff --git a/tests/TestSuite_pmd.py b/tests/TestSuite_pmd.py
index dccaade..a159143 100644
--- a/tests/TestSuite_pmd.py
+++ b/tests/TestSuite_pmd.py
@@ -183,7 +183,7 @@ class TestPmd(TestCase,IxiaPacketGenerator):
             core_mask = utils.create_mask(core_list)
             port_mask = utils.create_mask(self.dut.get_ports())
 
-            self.pmdout.start_testpmd(core_config, " --rxq=%d --txq=%d --portmask=%s --rss-ip --txrst=32 --txfreet=32 --txd=128 --txqflags=0xf01" % (queues, queues, port_mask), socket=self.ports_socket)
+            self.pmdout.start_testpmd(core_config, " --rxq=%d --txq=%d --portmask=%s --rss-ip --txrst=32 --txfreet=32 --txd=128 --tx-offloads=0" % (queues, queues, port_mask), socket=self.ports_socket)
 	    command_line = self.pmdout.get_pmd_cmd()
 
             info = "Executing PMD using %s\n" % test_cycle['cores']
diff --git a/tests/TestSuite_pmd_bonded.py b/tests/TestSuite_pmd_bonded.py
index f2d0616..a770b9b 100644
--- a/tests/TestSuite_pmd_bonded.py
+++ b/tests/TestSuite_pmd_bonded.py
@@ -812,7 +812,7 @@ UDP(sport=srcport, dport=destport)/Raw(load="\x50"*%s)], iface="%s", count=%d)'
         """
         if self._enable_perf:
             pmd_param = "--burst=32 --rxfreet=32 --mbcache=250 --txpt=32 \
---rxht=8 --rxwt=0 --txfreet=32 --txrst=32 --txqflags=0xf01"
+--rxht=8 --rxwt=0 --txfreet=32 --txrst=32 --tx-offloads=0"
             self.launch_app(pmd_param)
         else:
             self.launch_app()
diff --git a/tests/TestSuite_pmdrss_hash.py b/tests/TestSuite_pmdrss_hash.py
index 83bac40..227caaf 100644
--- a/tests/TestSuite_pmdrss_hash.py
+++ b/tests/TestSuite_pmdrss_hash.py
@@ -655,7 +655,7 @@ class TestPmdrssHash(TestCase):
     def test_dynamic_rss_bond_config(self):
         
         # setup testpmd and finish bond config
-        self.dut.send_expect("./%s/app/testpmd -c f -n 4 -- -i --txqflags=0" % self.target, "testpmd> ", 120)
+        self.dut.send_expect("./%s/app/testpmd -c f -n 4 -- -i --tx-offloads=0x8fff" % self.target, "testpmd> ", 120)
         out = self.dut.send_expect("create bonded device 3 0", "testpmd> ", 30)
         bond_device_id = int(re.search("port \d+", out).group().split(" ")[-1].strip())
 
diff --git a/tests/TestSuite_qinq_filter.py b/tests/TestSuite_qinq_filter.py
index 5ade49f..ad3e7ea 100644
--- a/tests/TestSuite_qinq_filter.py
+++ b/tests/TestSuite_qinq_filter.py
@@ -147,7 +147,7 @@ class TestQinqFilter(TestCase):
         
         self.dut.send_expect(r'./%s/app/testpmd -c %s -n 4 -- -i \
                                --portmask=%s --port-topology=loop \
-                               --rxq=4 --txq=4 --txqflags=0x0  --disable-rss' % (self.target, self.coreMask, self.portMask),
+                               --rxq=4 --txq=4 --tx-offloads=0x8fff  --disable-rss' % (self.target, self.coreMask, self.portMask),
                                "testpmd> ")
         self.dut.send_expect("vlan set qinq on %s" % dutRxPortId, "testpmd> ")
         self.dut.send_expect("set fwd rxonly", "testpmd> ")
@@ -167,7 +167,7 @@ class TestQinqFilter(TestCase):
         """
         self.dut.send_expect(r'./%s/app/testpmd -c %s -n 4 -- -i \
                                --portmask=%s --port-topology=loop \
-                               --rxq=4 --txq=4 --txqflags=0x0  --disable-rss' % (self.target, self.coreMask, self.portMask),
+                               --rxq=4 --txq=4 --tx-offloads=0x8fff  --disable-rss' % (self.target, self.coreMask, self.portMask),
                                "testpmd> ")
         self.dut.send_expect("vlan set qinq on %s" % dutRxPortId, "testpmd> ")
         self.dut.send_expect("set fwd rxonly", "testpmd> ")
@@ -203,7 +203,7 @@ class TestQinqFilter(TestCase):
 
         self.dut.send_expect(r'./%s/app/testpmd -c %s -n 4  \
                                --socket-mem=1024,1024 --file-prefix=pf -w %s -- -i --port-topology=loop \
-                               --rxq=4 --txq=4 --txqflags=0x0  --disable-rss' 
+                               --rxq=4 --txq=4 --tx-offloads=0x8fff  --disable-rss' 
                                % (self.target, self.coreMask, self.dut.ports_info[dutRxPortId]['pci']),
                                "testpmd> ")
         self.dut.send_expect("vlan set qinq on %s" % dutRxPortId, "testpmd> ")
@@ -220,13 +220,13 @@ class TestQinqFilter(TestCase):
 
         vf0_session.send_expect(r'./%s/app/testpmd -c %s -n 4  \
                                --socket-mem=1024,1024 --file-prefix=vf0 -w %s -- -i --port-topology=loop \
-                               --rxq=4 --txq=4 --txqflags=0x0  --disable-rss' 
+                               --rxq=4 --txq=4 --tx-offloads=0x8fff  --disable-rss' 
                                % (self.target, self.coreMask, vf_list[0]),
                                "testpmd> ")
                                                               
         vf1_session.send_expect(r'./%s/app/testpmd -c %s -n 4 \
                                --socket-mem=1024,1024 --file-prefix=vf1 -w %s -- -i --port-topology=loop \
-                               --rxq=4 --txq=4 --txqflags=0x0  --disable-rss' 
+                               --rxq=4 --txq=4 --tx-offloads=0x8fff  --disable-rss' 
                                % (self.target, self.coreMask, vf_list[1]),
                                "testpmd>") 
         for session_name in [vf0_session, vf1_session]:
@@ -272,7 +272,7 @@ class TestQinqFilter(TestCase):
 
         self.dut.send_expect(r'./%s/app/testpmd -c %s -n 4 \
                                --socket-mem=1024,1024 --file-prefix=pf -w %s -- -i --port-topology=loop \
-                               --rxq=4 --txq=4 --txqflags=0x0  --disable-rss' 
+                               --rxq=4 --txq=4 --tx-offloads=0x8fff  --disable-rss' 
                                % (self.target, self.coreMask, self.dut.ports_info[dutRxPortId]['pci']),
                                "testpmd> ")
         self.dut.send_expect("vlan set qinq on %s" % dutRxPortId, "testpmd> ")
@@ -292,13 +292,13 @@ class TestQinqFilter(TestCase):
         
         vf0_session.send_expect(r'./%s/app/testpmd -c %s -n 4 \
                                --socket-mem=1024,1024 --file-prefix=vf0 -w %s -- -i --port-topology=loop \
-                               --rxq=4 --txq=4 --txqflags=0x0  --disable-rss' 
+                               --rxq=4 --txq=4 --tx-offloads=0x8fff  --disable-rss' 
                                % (self.target, self.coreMask, vf_list[0]),
                                "testpmd> ")
                                                               
         vf1_session.send_expect(r'./%s/app/testpmd -c %s -n 4 \
                                --socket-mem=1024,1024 --file-prefix=vf1 -w %s -- -i --port-topology=loop \
-                               --rxq=4 --txq=4 --txqflags=0x0  --disable-rss' 
+                               --rxq=4 --txq=4 --tx-offloads=0x8fff  --disable-rss' 
                                % (self.target, self.coreMask, vf_list[1]),
                                "testpmd>") 
         for session_name in [vf0_session, vf1_session]:
diff --git a/tests/TestSuite_sriov_kvm.py b/tests/TestSuite_sriov_kvm.py
index 440306c..bcf4ed8 100644
--- a/tests/TestSuite_sriov_kvm.py
+++ b/tests/TestSuite_sriov_kvm.py
@@ -350,7 +350,7 @@ class TestSriovKvm(TestCase):
                 eal_param = '-b %(vf0)s -b %(vf1)s' % {'vf0': self.sriov_vfs_port[0].pci,
                                                        'vf1': self.sriov_vfs_port[1].pci}
                 self.host_testpmd.start_testpmd(
-                    "1S/2C/2T", "--rxq=4 --txq=4 --txqflags=0", eal_param=eal_param)
+                    "1S/2C/2T", "--rxq=4 --txq=4 --tx-offloads=0x8fff", eal_param=eal_param)
                 self.host_testpmd.execute_cmd('set fwd rxonly')
                 self.host_testpmd.execute_cmd('start')
 
diff --git a/tests/TestSuite_tso.py b/tests/TestSuite_tso.py
index 0689291..25b37a3 100644
--- a/tests/TestSuite_tso.py
+++ b/tests/TestSuite_tso.py
@@ -157,7 +157,7 @@ class TestTSO(TestCase):
         self.tester.send_expect("ethtool -K %s rx off tx off tso off gso off gro off lro off" % tx_interface, "# ")
         self.tester.send_expect("ip l set %s up" % tx_interface, "# ")
 
-        cmd = "./%s/app/testpmd -c %s -n %d %s -- -i --rxd=512 --txd=512 --burst=32 --rxfreet=64 --mbcache=128 --portmask=%s --txpt=36 --txht=0 --txwt=0 --txfreet=32 --txrst=32 --txqflags=0 " % (self.target, self.coreMask, self.dut.get_memory_channels(), self.blacklist, self.portMask)
+        cmd = "./%s/app/testpmd -c %s -n %d %s -- -i --rxd=512 --txd=512 --burst=32 --rxfreet=64 --mbcache=128 --portmask=%s --txpt=36 --txht=0 --txwt=0 --txfreet=32 --txrst=32 --tx-offloads=0x8fff " % (self.target, self.coreMask, self.dut.get_memory_channels(), self.blacklist, self.portMask)
         self.dut.send_expect(cmd, "testpmd> ", 120)
         self.dut.send_expect("set verbose 1", "testpmd> ", 120)
         self.dut.send_expect("csum set ip hw %d" % self.dut_ports[0], "testpmd> ", 120)
@@ -223,7 +223,7 @@ class TestTSO(TestCase):
         self.tester.send_expect("ethtool -K %s rx off tx off tso off gso off gro off lro off" % tx_interface, "# ")
         self.tester.send_expect("ip l set %s up" % tx_interface, "# ")
 
-        cmd = "./%s/app/testpmd -c %s -n %d %s -- -i --rxd=512 --txd=512 --burst=32 --rxfreet=64 --mbcache=128 --portmask=%s --txpt=36 --txht=0 --txwt=0 --txfreet=32 --txrst=32 --txqflags=0 " % (self.target, self.coreMask, self.dut.get_memory_channels(), self.blacklist, self.portMask)
+        cmd = "./%s/app/testpmd -c %s -n %d %s -- -i --rxd=512 --txd=512 --burst=32 --rxfreet=64 --mbcache=128 --portmask=%s --txpt=36 --txht=0 --txwt=0 --txfreet=32 --txrst=32 --tx-offloads=0x8fff " % (self.target, self.coreMask, self.dut.get_memory_channels(), self.blacklist, self.portMask)
         self.dut.send_expect(cmd, "testpmd> ", 120)
         self.dut.send_expect("set verbose 1", "testpmd> ", 120)
         self.dut.send_expect("csum set ip hw %d" % self.dut_ports[0], "testpmd> ", 120)
@@ -287,7 +287,7 @@ class TestTSO(TestCase):
             else:
                 queues = 1
 
-            command_line = "./%s/app/testpmd -c %s -n %d %s -- -i --coremask=%s --rxd=512 --txd=512 --burst=32 --rxfreet=64 --mbcache=128 --portmask=%s --txpt=36 --txht=0 --txwt=0 --txfreet=32 --txrst=32 --txqflags=0 " % (self.target, self.all_cores_mask, self.dut.get_memory_channels(), self.blacklist, self.coreMask, self.portMask)
+            command_line = "./%s/app/testpmd -c %s -n %d %s -- -i --coremask=%s --rxd=512 --txd=512 --burst=32 --rxfreet=64 --mbcache=128 --portmask=%s --txpt=36 --txht=0 --txwt=0 --txfreet=32 --txrst=32 --tx-offloads=0x8fff " % (self.target, self.all_cores_mask, self.dut.get_memory_channels(), self.blacklist, self.coreMask, self.portMask)
 
             info = "Executing PMD using %s\n" % test_cycle['cores']
             self.logger.info(info)
diff --git a/tests/TestSuite_uni_pkt.py b/tests/TestSuite_uni_pkt.py
index 6975f2d..945a51e 100644
--- a/tests/TestSuite_uni_pkt.py
+++ b/tests/TestSuite_uni_pkt.py
@@ -64,7 +64,7 @@ class TestUniPacket(TestCase):
         tester_port = self.tester.get_local_port(self.dut_port)
         self.tester_iface = self.tester.get_interface(tester_port)
         self.dut.send_expect(
-            "./%s/app/testpmd -c f -n 4 -- -i --txqflags=0x0" % self.target, "testpmd>", 20)
+            "./%s/app/testpmd -c f -n 4 -- -i --tx-offloads=0x8fff" % self.target, "testpmd>", 20)
         self.dut.send_expect("set fwd rxonly", "testpmd>")
         self.dut.send_expect("set verbose 1", "testpmd>")
         self.dut.send_expect("start", "testpmd>")
diff --git a/tests/TestSuite_vf_jumboframe.py b/tests/TestSuite_vf_jumboframe.py
index fc4971b..b711751 100644
--- a/tests/TestSuite_vf_jumboframe.py
+++ b/tests/TestSuite_vf_jumboframe.py
@@ -209,7 +209,7 @@ class TestVfJumboFrame(TestCase):
         self.dutobj = self.dut.ports_info[self.port]['port']
         self.dutobj.enable_jumbo(framesize=ETHER_STANDARD_MTU)
 
-        self.vm_testpmd.start_testpmd("Default", "--max-pkt-len=%d --port-topology=loop --txqflags=0x0" % (ETHER_STANDARD_MTU))
+        self.vm_testpmd.start_testpmd("Default", "--max-pkt-len=%d --port-topology=loop --tx-offloads=0x8fff" % (ETHER_STANDARD_MTU))
 
         self.vm_testpmd.execute_cmd("set fwd mac")
         self.vm_testpmd.execute_cmd("start")
@@ -229,7 +229,7 @@ class TestVfJumboFrame(TestCase):
         self.dutobj = self.dut.ports_info[self.port]['port']
         self.dutobj.enable_jumbo(framesize=ETHER_JUMBO_FRAME_MTU)
 
-        self.vm_testpmd.start_testpmd("Default", "--max-pkt-len=%d --port-topology=loop --txqflags=0x0" % (ETHER_JUMBO_FRAME_MTU))
+        self.vm_testpmd.start_testpmd("Default", "--max-pkt-len=%d --port-topology=loop --tx-offloads=0x8fff" % (ETHER_JUMBO_FRAME_MTU))
 
         self.vm_testpmd.execute_cmd("set fwd mac")
         self.vm_testpmd.execute_cmd("start")
@@ -249,7 +249,7 @@ class TestVfJumboFrame(TestCase):
         self.dutobj = self.dut.ports_info[self.port]['port']
         self.dutobj.enable_jumbo(framesize=ETHER_STANDARD_MTU)
 
-        self.vm_testpmd.start_testpmd("Default", "--port-topology=loop --txqflags=0x0" )
+        self.vm_testpmd.start_testpmd("Default", "--port-topology=loop --tx-offloads=0x8fff" )
 
         self.vm_testpmd.execute_cmd("set fwd mac")
         self.vm_testpmd.execute_cmd("start")
@@ -277,7 +277,7 @@ class TestVfJumboFrame(TestCase):
         self.dutobj = self.dut.ports_info[self.port]['port']
         self.dutobj.enable_jumbo(framesize=ETHER_JUMBO_FRAME_MTU)
 
-        self.vm_testpmd.start_testpmd("Default", "--max-pkt-len=%d --port-topology=loop --txqflags=0x0" % (ETHER_JUMBO_FRAME_MTU))
+        self.vm_testpmd.start_testpmd("Default", "--max-pkt-len=%d --port-topology=loop --tx-offloads=0x8fff" % (ETHER_JUMBO_FRAME_MTU))
 
         self.vm_testpmd.execute_cmd("set fwd mac")
         self.vm_testpmd.execute_cmd("start")
@@ -298,7 +298,7 @@ class TestVfJumboFrame(TestCase):
         self.dutobj = self.dut.ports_info[self.port]['port']
         self.dutobj.enable_jumbo(framesize=ETHER_JUMBO_FRAME_MTU)
 
-        self.vm_testpmd.start_testpmd("Default", "--max-pkt-len=%d --port-topology=loop --txqflags=0x0" % (ETHER_JUMBO_FRAME_MTU))
+        self.vm_testpmd.start_testpmd("Default", "--max-pkt-len=%d --port-topology=loop --tx-offloads=0x8fff" % (ETHER_JUMBO_FRAME_MTU))
 
         self.vm_testpmd.execute_cmd("set fwd mac")
         self.vm_testpmd.execute_cmd("start")
diff --git a/tests/TestSuite_vf_offload.py b/tests/TestSuite_vf_offload.py
index 61ef453..020207c 100644
--- a/tests/TestSuite_vf_offload.py
+++ b/tests/TestSuite_vf_offload.py
@@ -206,7 +206,7 @@ class TestVfOffload(TestCase):
         verify forwarded packets have correct checksum
         """
         self.vm0_testpmd.start_testpmd(VM_CORES_MASK, "--portmask=%s " %
-                                      (self.portMask) + "--disable-hw-vlan --enable-rx-cksum " + "--txqflags=0 " +
+                                      (self.portMask) + "--disable-hw-vlan --enable-rx-cksum " + "--tx-offloads=0x8fff " +
                                       "--port-topology=loop")
         self.vm0_testpmd.execute_cmd('set fwd csum')
 
@@ -348,7 +348,7 @@ class TestVfOffload(TestCase):
         self.portMask = utils.create_mask([self.vm0_dut_ports[0]])
         self.vm0_testpmd.start_testpmd(VM_CORES_MASK, "--portmask=%s " %
                                       (self.portMask) + "--enable-rx-cksum " +
-                                      "--txqflags=0 " + 
+                                      "--tx-offloads=0x8fff " + 
                                       "--port-topology=loop")
 
         mac = self.vm0_testpmd.get_port_mac(0)
diff --git a/tests/TestSuite_vhost_cuse_one_copy_one_vm.py b/tests/TestSuite_vhost_cuse_one_copy_one_vm.py
index 415ab0d..573419a 100644
--- a/tests/TestSuite_vhost_cuse_one_copy_one_vm.py
+++ b/tests/TestSuite_vhost_cuse_one_copy_one_vm.py
@@ -129,13 +129,13 @@ class TestVhostCuseOneCopyOneVm(TestCase, IxiaPacketGenerator):
             self.jumbo = 1
             self.frame_sizes = [64, 128, 256, 512, 1024, 1280, 1518, 2048, 5000, 9000]
             self.vm_testpmd = "./x86_64-native-linuxapp-gcc/app/testpmd -c 0x3 -n 3" \
-                + " -- -i --txqflags=0xf00 " \
+                + " -- -i --tx-offloads=0x8000 " \
                 + "--disable-hw-vlan-filter --max-pkt-len 9600"
         else:
             self.jumbo = 0
             self.frame_sizes = [64, 128, 256, 512, 1024, 1280, 1518]
             self.vm_testpmd = "./x86_64-native-linuxapp-gcc/app/testpmd -c 0x3 -n 3" \
-                + " -- -i --txqflags=0xf00 --disable-hw-vlan-filter"
+                + " -- -i --tx-offloads=0x8000 --disable-hw-vlan-filter"
         self.dut.send_expect("rm -rf ./vhost.out", "#")
 
         self.launch_vhost_sample()
diff --git a/tests/TestSuite_vhost_loopback_performance_virtio_user.py b/tests/TestSuite_vhost_loopback_performance_virtio_user.py
index 4e1449d..4f2851f 100644
--- a/tests/TestSuite_vhost_loopback_performance_virtio_user.py
+++ b/tests/TestSuite_vhost_loopback_performance_virtio_user.py
@@ -97,7 +97,7 @@ class TestVhostLoopback(TestCase):
             command_line_user = self.target + "/app/testpmd -n 4 -c 0x0c " + \
                                 " -m 2048 --no-pci --file-prefix=virtio " + \
                                 " --vdev=net_virtio_user0,mac=00:01:02:03:04:05,path=./vhost-net" + \
-                                " -- -i --txqflags=0xf01 --disable-hw-vlan-filter"
+                                " -- -i --tx-offloads=0 --disable-hw-vlan-filter"
 
             vhost_user.send_expect(command_line_user, "testpmd>", 120)
 
@@ -156,7 +156,7 @@ class TestVhostLoopback(TestCase):
             command_line_user = self.target + "/app/testpmd -n 4 -c 0x0c " + \
                                 " -m 2048 --no-pci --file-prefix=virtio " + \
                                 " --vdev=net_virtio_user0,mac=00:01:02:03:04:05,path=./vhost-net " + \
-                                " -- -i --txqflags=0xf01 --disable-hw-vlan-filter"
+                                " -- -i --tx-offloads=0 --disable-hw-vlan-filter"
 
             vhost_user.send_expect(command_line_user, "testpmd>", 120)
 
@@ -215,7 +215,7 @@ class TestVhostLoopback(TestCase):
             command_line_user = self.target + "/app/testpmd -n 4 -c 0x0c " + \
                                 " -m 2048 --no-pci --file-prefix=virtio " + \
                                 " --vdev=net_virtio_user0,mac=00:01:02:03:04:05,path=./vhost-net" + \
-                                " -- -i --txqflags=0xf00 --disable-hw-vlan-filter"
+                                " -- -i --tx-offloads=0x8000 --disable-hw-vlan-filter"
 
             vhost_user.send_expect(command_line_user, "testpmd>", 120)
 
diff --git a/tests/TestSuite_vhost_pmd_xstats.py b/tests/TestSuite_vhost_pmd_xstats.py
index 2b95536..8c800c7 100644
--- a/tests/TestSuite_vhost_pmd_xstats.py
+++ b/tests/TestSuite_vhost_pmd_xstats.py
@@ -86,7 +86,7 @@ class TestVhostPmdXstats(TestCase):
         """
         Start testpmd in vm
         """
-        self.vm_testpmd = "./%s/app/testpmd -c 0x3 -n 4 -- -i --txqflags=0xf01" % self.target
+        self.vm_testpmd = "./%s/app/testpmd -c 0x3 -n 4 -- -i --tx-offloads=0" % self.target
         if self.vm_dut is not None:
             self.vm_dut.send_expect(self.vm_testpmd, "testpmd>", 60)
 
diff --git a/tests/TestSuite_vhost_qemu_pvp_performance.py b/tests/TestSuite_vhost_qemu_pvp_performance.py
index a9945d5..051c9a2 100644
--- a/tests/TestSuite_vhost_qemu_pvp_performance.py
+++ b/tests/TestSuite_vhost_qemu_pvp_performance.py
@@ -107,9 +107,9 @@ class TestVhostUserOneCopyOneVm(TestCase):
 
         self.frame_sizes = [64, 128, 256, 512, 1024, 1500]
         self.vm_testpmd_vector = self.target + "/app/testpmd -c 0x3 -n 3" \
-                                 + " -- -i --txqflags=0xf01 --disable-hw-vlan-filter"
+                                 + " -- -i --tx-offloads=0 --disable-hw-vlan-filter"
         self.vm_testpmd_normal = self.target + "/app/testpmd -c 0x3 -n 3" \
-                                 + " -- -i --txqflags=0xf00 --disable-hw-vlan-filter"
+                                 + " -- -i --tx-offloads=0x8000 --disable-hw-vlan-filter"
 
     def launch_vhost_sample(self):
         #
diff --git a/tests/TestSuite_vhost_user_one_copy_one_vm.py b/tests/TestSuite_vhost_user_one_copy_one_vm.py
index f9e9430..ae7b5e9 100644
--- a/tests/TestSuite_vhost_user_one_copy_one_vm.py
+++ b/tests/TestSuite_vhost_user_one_copy_one_vm.py
@@ -121,13 +121,13 @@ class TestVhostUserOneCopyOneVm(TestCase, IxiaPacketGenerator):
             self.jumbo = 1
             self.frame_sizes = [64, 128, 256, 512, 1024, 1280, 1518, 2048, 5000, 9000]
             self.vm_testpmd = "./x86_64-native-linuxapp-gcc/app/testpmd -c 0x3 -n 3" \
-                + " -- -i --txqflags=0xf00 " \
+                + " -- -i --tx-offloads=0x8000 " \
                 + "--disable-hw-vlan-filter --max-pkt-len 9600"
         else:
             self.jumbo = 0
             self.frame_sizes = [64, 128, 256, 512, 1024, 1280, 1518]
             self.vm_testpmd = "./x86_64-native-linuxapp-gcc/app/testpmd -c 0x3 -n 3" \
-                + " -- -i --txqflags=0xf00 --disable-hw-vlan-filter"
+                + " -- -i --tx-offloads=0x8000 --disable-hw-vlan-filter"
         self.dut.send_expect("rm -rf ./vhost.out", "#")
 
         self.launch_vhost_sample()
diff --git a/tests/TestSuite_vxlan.py b/tests/TestSuite_vxlan.py
index b1f6f10..fe24b7e 100644
--- a/tests/TestSuite_vxlan.py
+++ b/tests/TestSuite_vxlan.py
@@ -547,7 +547,7 @@ class TestVxlan(TestCase, IxiaPacketGenerator):
         
         pmd_temp = "./%(TARGET)s/app/testpmd -c %(COREMASK)s -n " + \
             "%(CHANNEL)d -- -i --disable-rss --rxq=4 --txq=4" + \
-            " --nb-cores=4 --portmask=%(PORT)s --txqflags=0x0"
+            " --nb-cores=4 --portmask=%(PORT)s --tx-offloads=0x8fff"
         pmd_cmd = pmd_temp % {'TARGET': self.target,
                               'COREMASK': self.coremask,
                               'CHANNEL': self.dut.get_memory_channels(),
@@ -597,7 +597,7 @@ class TestVxlan(TestCase, IxiaPacketGenerator):
 
         pmd_temp = "./%(TARGET)s/app/testpmd -c %(COREMASK)s -n " + \
             "%(CHANNEL)d -- -i --disable-rss --rxq=4 --txq=4" + \
-            " --nb-cores=4 --portmask=%(PORT)s --txqflags=0x0"
+            " --nb-cores=4 --portmask=%(PORT)s --tx-offloads=0x8fff"
         pmd_cmd = pmd_temp % {'TARGET': self.target,
                               'COREMASK': self.coremask,
                               'CHANNEL': self.dut.get_memory_channels(),
@@ -644,7 +644,7 @@ class TestVxlan(TestCase, IxiaPacketGenerator):
         # start testpmd with 2queue/1port
         pmd_temp = "./%(TARGET)s/app/testpmd -c %(COREMASK)s -n " + \
             "%(CHANNEL)d -- -i --portmask=%(PORT)s " + \
-            "--txqflags=0x0 --enable-rx-cksum"
+            "--tx-offloads=0x8fff --enable-rx-cksum"
         pmd_cmd = pmd_temp % {'TARGET': self.target,
                               'COREMASK': self.coremask,
                               'CHANNEL': self.dut.get_memory_channels(),
@@ -717,7 +717,7 @@ class TestVxlan(TestCase, IxiaPacketGenerator):
         # start testpmd with 2queue/1port
         pmd_temp = "./%(TARGET)s/app/testpmd -c %(COREMASK)s -n " + \
             "%(CHANNEL)d -- -i --portmask=%(PORT)s " + \
-            "--txqflags=0x0 --enable-rx-cksum"
+            "--tx-offloads=0x8fff --enable-rx-cksum"
         pmd_cmd = pmd_temp % {'TARGET': self.target,
                               'COREMASK': self.coremask,
                               'CHANNEL': self.dut.get_memory_channels(),
@@ -792,7 +792,7 @@ class TestVxlan(TestCase, IxiaPacketGenerator):
         """
         pmd_temp = "./%(TARGET)s/app/testpmd -c %(COREMASK)s -n " + \
             "%(CHANNEL)d -- -i --disable-rss --rxq=4 --txq=4" + \
-            " --nb-cores=4 --portmask=%(PORT)s --txqflags=0x0"
+            " --nb-cores=4 --portmask=%(PORT)s --tx-offloads=0x8fff"
         pmd_cmd = pmd_temp % {'TARGET': self.target,
                               'COREMASK': self.coremask,
                               'CHANNEL': self.dut.get_memory_channels(),
@@ -833,7 +833,7 @@ class TestVxlan(TestCase, IxiaPacketGenerator):
 
         pmd_temp = "./%(TARGET)s/app/testpmd -c %(COREMASK)s -n " + \
             "%(CHANNEL)d -- -i --disable-rss --rxq=4 --txq=4" + \
-            " --nb-cores=4 --portmask=%(PORT)s --txqflags=0x0"
+            " --nb-cores=4 --portmask=%(PORT)s --tx-offloads=0x8fff"
         pmd_cmd = pmd_temp % {'TARGET': self.target,
                               'COREMASK': self.coremask,
                               'CHANNEL': self.dut.get_memory_channels(),
@@ -962,7 +962,7 @@ class TestVxlan(TestCase, IxiaPacketGenerator):
 
         pmd_temp = "./%(TARGET)s/app/testpmd -c %(COREMASK)s -n " + \
             "%(CHANNEL)d -- -i --disable-rss --rxq=2 --txq=2" + \
-            " --nb-cores=4 --portmask=%(PORT)s --txqflags=0x0"
+            " --nb-cores=4 --portmask=%(PORT)s --tx-offloads=0x8fff"
 
         for perf_config in self.tunnel_perf:
             tun_filter = perf_config['tunnel_filter']
@@ -973,7 +973,7 @@ class TestVxlan(TestCase, IxiaPacketGenerator):
             if tun_filter == "None" and recv_queue == "Multi":
                 pmd_temp = "./%(TARGET)s/app/testpmd -c %(COREMASK)s -n " + \
                     "%(CHANNEL)d -- -i --rss-udp --rxq=2 --txq=2" + \
-                    " --nb-cores=4 --portmask=%(PORT)s --txqflags=0x0"
+                    " --nb-cores=4 --portmask=%(PORT)s --tx-offloads=0x8fff"
 
             pmd_cmd = pmd_temp % {'TARGET': self.target,
                                   'COREMASK': core_mask,
@@ -1074,11 +1074,11 @@ class TestVxlan(TestCase, IxiaPacketGenerator):
             if recv_queue == 'Multi':
                 pmd_temp = "./%(TARGET)s/app/testpmd -c %(COREMASK)s -n " + \
                     "%(CHANNEL)d -- -i --disable-rss --rxq=2 --txq=2" + \
-                    " --nb-cores=4 --portmask=%(PORT)s --txqflags=0x0"
+                    " --nb-cores=4 --portmask=%(PORT)s --tx-offloads=0x8fff"
             else:
                 pmd_temp = "./%(TARGET)s/app/testpmd -c %(COREMASK)s -n " + \
                     "%(CHANNEL)d -- -i --nb-cores=2 --portmask=%(PORT)s" + \
-                    " --txqflags=0x0"
+                    " --tx-offloads=0x8fff"
 
             pmd_cmd = pmd_temp % {'TARGET': self.target,
                                   'COREMASK': core_mask,
diff --git a/tests/TestSuite_vxlan_sample.py b/tests/TestSuite_vxlan_sample.py
index 8115a18..fe8580f 100644
--- a/tests/TestSuite_vxlan_sample.py
+++ b/tests/TestSuite_vxlan_sample.py
@@ -102,7 +102,7 @@ class TestVxlanSample(TestCase):
         self.tep_app = "./examples/tep_termination/build/tep_termination"
         self.vxlan_port = 4789
         self.vm_testpmd = "./x86_64-native-linuxapp-gcc/app/testpmd -c f -n 3" \
-                          + " -- -i --txqflags=0xf00 --disable-hw-vlan"
+                          + " -- -i --tx-offloads=0x8000 --disable-hw-vlan"
 
         # params for tep_termination
         self.cores = self.dut.get_core_list("1S/4C/1T", socket=self.socket)
diff --git a/framework/pmd_output.py b/framework/pmd_output.py
index 2d1e3d7..0c1dfc6 100644
--- a/framework/pmd_output.py
+++ b/framework/pmd_output.py
@@ -101,9 +101,9 @@ class PmdOutput():
         return self.command
 
     def start_testpmd(self, cores, param='', eal_param='', socket=0):
-        # in dpdk2.0 need used --txqflags param to open hardware features
-        if "--txqflags" not in param:
-            param += " --txqflags=0"
+        # in dpdk18.02 need used --tx-offloads param to open hardware features
+        if "--tx-offloads" not in param:
+            param += " --tx-offloads=0x8fff"
 
         if type(cores) == list:
             core_list = cores
-- 
1.8.3.1



More information about the dts mailing list